
//
//  File: DetailViewManager.m
//  CoreDataLibraryApp
//  Abstract: The split view controller's delegate.  It coordinates the display of detail view controllers.
//
//  Created by Duncan Groenewald on 11/02/2014.
//  Copyright (c) 2014 OSSH Pty Ltd. All rights reserved.
//

#import "DetailViewManager.h"
#import "Macros.h"

@interface DetailViewManager ()
// Holds a reference to the split view controller's bar button item
// if the button should be shown (the device is in portrait).
// Will be nil otherwise.
@property (nonatomic, strong) UIBarButtonItem *navigationPaneButtonItem;
// Holds a reference to the popover that will be displayed
// when the navigation button is pressed.
@property (nonatomic, strong) UIPopoverController *navigationPopoverController;
@end


@implementation DetailViewManager

// -------------------------------------------------------------------------------
//	setDetailViewController:
//  Custom implementation of the setter for the detailViewController property.
// -------------------------------------------------------------------------------
- (void)setDetailViewController:(UIViewController<SubstitutableDetailViewController> *)detailViewController
{
    //FLOG(@" called");
    // Clear any bar button item from the detail view controller that is about to
    // no longer be displayed.
    self.detailViewController.navigationPaneBarButtonItem = nil;
    
    _detailViewController = detailViewController;
    
    // Set the new detailViewController's navigationPaneBarButtonItem to the value of our
    // navigationPaneButtonItem.  If navigationPaneButtonItem is not nil, then the button 
    // will be displayed.
    
    // Update the split view controller's view controllers array.
    // This causes the new detail view controller to be displayed.
    UIViewController *navigationViewController = [self.splitViewController.viewControllers objectAtIndex:0];
    
    UINavigationController *nc = [[UINavigationController alloc] initWithRootViewController:_detailViewController];
    _detailViewController.navigationBar = nc.navigationBar;
    _detailViewController.navigationPaneBarButtonItem = self.navigationPaneButtonItem;
    
    
    //FLOG(@" detailViewController is %@", detailViewController);
    NSArray *viewControllers = [[NSArray alloc] initWithObjects:navigationViewController, nc, nil];
    
    self.splitViewController.viewControllers = viewControllers;
    
    // Dismiss the navigation popover if one was present unless we are displaying the openingViewController.  This will
    // only occur if the device is in portrait.
    FLOG(@" openingViewController is %@", self.openingViewController);
    if (self.navigationPopoverController && (_detailViewController != self.openingViewController))
        [self.navigationPopoverController dismissPopoverAnimated:YES];
}
- (void)showOpeningViewController {
    //FLOG(@" called");
    //FLOG(@" openingViewController is %@", self.openingViewController);
    
    if (self.detailViewController != self.openingViewController)
        [self setDetailViewController:self.openingViewController];
}
#pragma mark -
#pragma mark UISplitViewDelegate

// -------------------------------------------------------------------------------
//	splitViewController:shouldHideViewController:inOrientation:
// -------------------------------------------------------------------------------
- (BOOL)splitViewController:(UISplitViewController *)svc 
   shouldHideViewController:(UIViewController *)vc 
              inOrientation:(UIInterfaceOrientation)orientation
{
    //FLOG(@" called");

    return UIInterfaceOrientationIsPortrait(orientation);
}

// -------------------------------------------------------------------------------
//	splitViewController:willHideViewController:withBarButtonItem:forPopoverController:
// -------------------------------------------------------------------------------
- (void)splitViewController:(UISplitViewController *)svc 
     willHideViewController:(UIViewController *)aViewController 
          withBarButtonItem:(UIBarButtonItem *)barButtonItem 
       forPopoverController:(UIPopoverController *)pc
{
    //FLOG(@" called");

    // If the barButtonItem does not have a title (or image) adding it to a toolbar
    // will do nothing.
    barButtonItem.title = @"Navigation";
    
    self.navigationPaneButtonItem = barButtonItem;
    self.navigationPopoverController = pc;
    
    // Tell the detail view controller to show the navigation button.
    self.detailViewController.navigationPaneBarButtonItem = barButtonItem;
}

// -------------------------------------------------------------------------------
//	splitViewController:willShowViewController:invalidatingBarButtonItem:
// -------------------------------------------------------------------------------
- (void)splitViewController:(UISplitViewController *)svc 
     willShowViewController:(UIViewController *)aViewController 
  invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
{
    //FLOG(@" called");

    self.navigationPaneButtonItem = nil;
    self.navigationPopoverController = nil;
    
    // Tell the detail view controller to remove the navigation button.
    self.detailViewController.navigationPaneBarButtonItem = nil;
}


@end
